@@ -3,7 +3,6 @@
 ConvertPathToHierarchy<-function(list_path,list_value,root_in=FALSE)
 {
   res=list()
-  print(root_in)
 
 
   unique_elt<-unique(unlist(lapply(1:length(list_path),function(x){list_path[[x]][1]})))
@@ -53,3 +52,12 @@ generateRandomPath<-function(step=6,n_path=1000)
   return(RandomData[[1]])
 }
 
+
+require(graphics)
+
+
+
+
+
+
+
